==> stoobly_agent-1.1.1.tar.gz: stoobly_agent-1.1.1/stoobly_agent/app/cli/scaffold/app.py <==
import os
import shutil

from stoobly_agent.config.data_dir import DataDir, DATA_DIR_NAME

class App():

  def __init__(self, path: str, namespace: str, **kwargs):
    path = path or os.getcwd()
    data_dir: DataDir = DataDir.instance(path) 

    self.__scaffold_dir_path = data_dir.path
    self.__ca_certs_dir_path = kwargs.get('ca_certs_dir_path') or data_dir.mitmproxy_conf_dir_path
    self.__certs_dir_path = data_dir.certs_dir_path
    self.__context_dir_path = data_dir.context_dir_path
    self.__data_dir = data_dir
    self.__dir_path = path
    self.__name = os.path.basename(self.__dir_path)
    self.__network = os.path.basename(self.__dir_path)
    self.__namespace = namespace
    self.__skip_validate_path = not not kwargs.get('skip_validate_path')

  @property
  def ca_certs_dir_path(self):
    return self.__ca_certs_dir_path

  @ca_certs_dir_path.setter
  def ca_certs_dir_path(self, v: str):
    self.__validate_path(v)
    self.__certs_dir_path = v

  @property
  def certs_dir_path(self):
    return self.__certs_dir_path

  @certs_dir_path.setter
  def certs_dir_path(self, v: str):
    self.__validate_path(v)
    self.__certs_dir_path = v

  @property
  def context_dir_path(self):
    return self.__context_dir_path

  @context_dir_path.setter
  def context_dir_path(self, v: str):
    self.__validate_path(v)
    self.__context_dir_path = v 

  @property
  def data_dir(self):
    return self.__data_dir

  @property
  def data_dir_path(self):
    return os.path.join(self.context_dir_path, DATA_DIR_NAME)

  @property
  def exists(self):
    return os.path.exists(self.dir_path)

  @property
  def name(self):
    return self.__name

  @name.setter
  def name(self, v: str):
    self.__name = v

  @property
  def network(self):
    return self.__network

  @network.setter
  def network(self, v: str):
    self.__network = v

  @property
  def namespace(self):
    return self.__namespace

  @property
  def namespace_path(self):
    return os.path.join(self.data_dir_path, self.namespace)

  @property
  def dir_path(self):
    return self.__dir_path

  @property
  def scaffold_dir_path(self):
    return self.__scaffold_dir_path

  @property
  def scaffold_namespace_path(self):
    return os.path.join(self.scaffold_dir_path, self.namespace)

  @property
  def services(self):
    return list(map(lambda path: os.path.basename(path), self.service_paths))

  @property
  def service_paths(self):
    services_dir = os.path.join(self.scaffold_dir_path, self.namespace)

    services = []
    for filename in os.listdir(services_dir):
      path = os.path.join(services_dir, filename)
      if not os.path.isdir(path):
        continue
      
      services.append(path)

    return services

  def copy_folders_and_hidden_files(self, src, dst):
      os.makedirs(dst, exist_ok=True)

      # Walk through the source directory
      for root, dirs, files in os.walk(src):
          # Copy hidden files only
          for file_name in files:
              src_file_path = os.path.join(root, file_name)
              dst_file_path = os.path.join(dst, os.path.relpath(root, src), file_name)

              if not file_name.startswith('.'):
                  if os.path.exists(dst_file_path):
                      continue

              os.makedirs(os.path.dirname(dst_file_path), exist_ok=True)  # Create directories in destination
              shutil.copy2(src_file_path, dst_file_path)

  def __validate_path(self, v: str):
    if not isinstance(v, str):
      raise TypeError('Expected a str')

    if not self.__skip_validate_path:
      if not os.path.exists(v):
        raise ValueError(f"{v} does not exist")

==> stoobly_agent-1.10.2.tar.gz: stoobly_agent-1.10.2/stoobly_agent/app/cli/scaffold/app.py <==
import hashlib
import os
import re
import shutil

from stoobly_agent.config.data_dir import DataDir, DATA_DIR_NAME

class App():

  def __init__(self, path: str, scaffold_namespace: str, **kwargs):
    path = os.path.abspath(path) or os.getcwd()
    data_dir: DataDir = DataDir.instance(path) 

    self.__data_dir_path = data_dir.path
    self.__ca_certs_dir_path = kwargs.get('ca_certs_dir_path') or data_dir.ca_certs_dir_path
    self.__certs_dir_path = kwargs.get('certs_dir_path') or data_dir.certs_dir_path
    self.__context_dir_path = kwargs.get('context_dir_path') or data_dir.context_dir_path
    self.__data_dir = data_dir
    self.__dir_path = path
    self.__scaffold_namespace = scaffold_namespace
    self.__skip_validate_path = not not kwargs.get('dry_run')

  @property
  def ca_certs_dir_path(self):
    return self.__ca_certs_dir_path

  @ca_certs_dir_path.setter
  def ca_certs_dir_path(self, v: str):
    self.__validate_path(v)
    self.__certs_dir_path = v

  @property
  def certs_dir_path(self):
    return self.__certs_dir_path

  @certs_dir_path.setter
  def certs_dir_path(self, v: str):
    self.__validate_path(v)
    self.__certs_dir_path = v

  @property
  def context_dir_path(self):
    return self.__context_dir_path

  @context_dir_path.setter
  def context_dir_path(self, v: str):
    self.__validate_path(v)
    self.__context_dir_path = v 

  @property
  def data_dir(self):
    return self.__data_dir

  @property
  def data_dir_path(self):
    return os.path.join(self.context_dir_path, DATA_DIR_NAME)

  @property
  def valid(self):
    return os.path.exists(self.scaffold_namespace_path)

  @property
  def scaffold_namespace(self):
    return self.__scaffold_namespace

  @property
  def dir_path(self):
    return self.__dir_path

  @property
  def data_dir_path(self):
    return self.__data_dir_path

  @property
  def network(self):
    # An app may contain one or more context dirs from which services will derive their mocks from
    return hashlib.md5(self.context_dir_path.encode()).hexdigest()

  @property
  def scaffold_namespace_path(self):
    return os.path.join(self.data_dir_path, self.scaffold_namespace)

  @property
  def services(self):
    return list(map(lambda path: os.path.basename(path), self.service_paths))

  @property
  def service_paths(self):
    services_dir = os.path.join(self.data_dir_path, self.scaffold_namespace)

    services = []
    for filename in os.listdir(services_dir):
      path = os.path.join(services_dir, filename)
      if not os.path.isdir(path):
        continue
      
      services.append(path)

    return services

  def copy_folders_and_hidden_files(self, src: str, dst: str, ignore: list = []):
      os.makedirs(dst, exist_ok=True)

      # Walk through the source directory
      for root, dirs, files in os.walk(src):
          # Copy hidden files only
          for file_name in files:
              src_file_path = os.path.join(root, file_name)

              ignored = False

              # Skip files that match the ignore list pattern, use regex
              for ignore_pattern in ignore:
                  if re.match(os.path.join(src, ignore_pattern), src_file_path):
                      ignored = True
                      break

              if ignored:
                continue

              dst_file_path = os.path.join(dst, os.path.relpath(root, src), file_name)

              if not file_name.startswith('.'):
                  if os.path.exists(dst_file_path):
                      continue

              os.makedirs(os.path.dirname(dst_file_path), exist_ok=True)  # Create directories in destination
              shutil.copy2(src_file_path, dst_file_path)

  def __validate_path(self, v: str):
    if not isinstance(v, str):
      raise TypeError('Expected a str')

    if not self.__skip_validate_path:
      if not os.path.exists(v):
        raise ValueError(f"{v} does not exist")
